@@ -180,9 +180,13 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
                 if (charTotal)
                     ffStrbufSetS(&options->barCharTotal, charTotal);
 
-                yyjson_val* border = yyjson_obj_get(val, "border");
-                if (border)
-                    options->barBorder = yyjson_get_bool(border);
+                yyjson_val* borderLeft = yyjson_obj_get(val, "borderLeft");
+                if (borderLeft)
+                    ffStrbufSetS(&options->barBorderLeft, yyjson_get_str(borderLeft));
+
+                yyjson_val* borderRight = yyjson_obj_get(val, "borderRight");
+                if (borderRight)
+                    ffStrbufSetS(&options->barBorderRight, yyjson_get_str(borderRight));
 
                 yyjson_val* width = yyjson_obj_get(val, "width");
                 if (width)
@@ -196,7 +200,7 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
         else if (ffStrEqualsIgnCase(key, "keyWidth"))
             options->keyWidth = (uint32_t) yyjson_get_uint(val);
         else if (ffStrEqualsIgnCase(key, "tsVersion"))
-            options->tsVersion = yyjson_get_bool(val);
+            return "display.tsVersion has been renamed to general.detectVersion";
         else
             return "Unknown display property";
     }
@@ -346,13 +350,13 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
             ffOptionParseString(key, value, &options->barCharTotal);
         else if(ffStrEqualsIgnCase(subkey, "width"))
             options->barWidth = (uint8_t) ffOptionParseUInt32(key, value);
-        else if(ffStrEqualsIgnCase(subkey, "border"))
-            options->barBorder = ffOptionParseBoolean(value);
+        else if(ffStrEqualsIgnCase(subkey, "border-left"))
+            ffOptionParseString(key, value, &options->barBorderLeft);
+        else if(ffStrEqualsIgnCase(subkey, "border-right"))
+            ffOptionParseString(key, value, &options->barBorderRight);
         else
             return false;
     }
-    else if(ffStrEqualsIgnCase(key, "--ts-version"))
-        options->tsVersion = ffOptionParseBoolean(value);
     else
         return false;
     return true;
@@ -364,7 +368,7 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     ffStrbufInit(&options->colorTitle);
     ffStrbufInit(&options->colorOutput);
     ffStrbufInit(&options->colorSeparator);
-    options->brightColor = true;
+    options->brightColor = !instance.state.terminalLightTheme;
     ffStrbufInitStatic(&options->keyValueSeparator, ": ");
 
     options->showErrors = false;
@@ -387,20 +391,19 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     options->tempUnit = FF_TEMPERATURE_UNIT_CELSIUS;
     options->tempNdigits = 1;
     ffStrbufInitStatic(&options->tempColorGreen, FF_COLOR_FG_GREEN);
-    ffStrbufInitStatic(&options->tempColorYellow, FF_COLOR_FG_LIGHT_YELLOW);
-    ffStrbufInitStatic(&options->tempColorRed, FF_COLOR_FG_LIGHT_RED);
+    ffStrbufInitStatic(&options->tempColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
+    ffStrbufInitStatic(&options->tempColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
 
     ffStrbufInitStatic(&options->barCharElapsed, "■");
     ffStrbufInitStatic(&options->barCharTotal, "-");
+    ffStrbufInitStatic(&options->barBorderLeft, "[ ");
+    ffStrbufInitStatic(&options->barBorderRight, " ]");
     options->barWidth = 10;
-    options->barBorder = true;
     options->percentType = 9;
     options->percentNdigits = 0;
     ffStrbufInitStatic(&options->percentColorGreen, FF_COLOR_FG_GREEN);
-    ffStrbufInitStatic(&options->percentColorYellow, FF_COLOR_FG_LIGHT_YELLOW);
-    ffStrbufInitStatic(&options->percentColorRed, FF_COLOR_FG_LIGHT_RED);
-
-    options->tsVersion = true;
+    ffStrbufInitStatic(&options->percentColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
+    ffStrbufInitStatic(&options->percentColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
 }
 
 void ffOptionsDestroyDisplay(FFOptionsDisplay* options)
@@ -561,8 +564,10 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
             yyjson_mut_obj_add_strbuf(doc, bar, "charElapsed", &options->barCharElapsed);
         if (!ffStrbufEqual(&options->barCharTotal, &defaultOptions.barCharTotal))
             yyjson_mut_obj_add_strbuf(doc, bar, "charTotal", &options->barCharTotal);
-        if (options->barBorder != defaultOptions.barBorder)
-            yyjson_mut_obj_add_bool(doc, bar, "border", options->barBorder);
+        if (!ffStrbufEqual(&options->barBorderLeft, &defaultOptions.barBorderLeft))
+            yyjson_mut_obj_add_strbuf(doc, bar, "borderLeft", &options->barBorderLeft);
+        if (!ffStrbufEqual(&options->barBorderRight, &defaultOptions.barBorderRight))
+            yyjson_mut_obj_add_strbuf(doc, bar, "borderRight", &options->barBorderRight);
         if (options->barWidth != defaultOptions.barWidth)
             yyjson_mut_obj_add_uint(doc, bar, "width", options->barWidth);
 
